pub fn vectors_to_arrow_ipc(
blobs: &[Vec<u8>],
vtype: VectorType,
dim: usize,
) -> Result<Vec<u8>, ArrowError>Expand description
Convert a list of raw vector blobs into an Arrow IPC byte buffer.
pub fn vectors_to_arrow_ipc(
blobs: &[Vec<u8>],
vtype: VectorType,
dim: usize,
) -> Result<Vec<u8>, ArrowError>Convert a list of raw vector blobs into an Arrow IPC byte buffer.