pub struct VectorCursor {
pub mode: CursorMode,
pub num_metadata_cols: usize,
pub db: *const VTabConnection,
pub config: *const VectorTableConfig,
pub state: Arc<RefCell<IndexState>>,
}Fields
mode: CursorModenum_metadata_cols: usizedb: *const VTabConnectionSafety: valid for the vtab lifetime — SQLite keeps the connection alive.
config: *const VectorTableConfigSafety: valid for the vtab lifetime — VectorTable owns the config.
state: Arc<RefCell<IndexState>>Trait Implementations
Sourceimpl VTabCursor for VectorCursor
impl VTabCursor for VectorCursor
Sourcefn filter(
&mut self,
index_num: i32,
_index_str: Option<&str>,
args: &mut [&mut ValueRef],
) -> Result<()>
fn filter( &mut self, index_num: i32, _index_str: Option<&str>, args: &mut [&mut ValueRef], ) -> Result<()>
Sourcefn eof(&mut self) -> bool
fn eof(&mut self) -> bool
Check if the cursor currently points beyond the end of the valid results.
Sourcefn column(&mut self, idx: usize, ctx: &ColumnContext) -> Result<()>
fn column(&mut self, idx: usize, ctx: &ColumnContext) -> Result<()>
Fetch the column numbered idx for the current row. The indexes correspond to the order the
columns were declared by VTab::connect. The output value must be assigned to the context
using ColumnContext::set_result. If no result is set, SQL NULL is returned. If this
method returns an Err value, the SQL statement will fail, even if a result had been set
before the failure.
impl Send for VectorCursor
impl Sync for VectorCursor