VectorTable

Struct VectorTable 

pub struct VectorTable<'vtab> { /* private fields */ }
The virtual table implementation for vector search.

db is a raw pointer to the VTabConnection that SQLite provides to connect/create. SQLite guarantees the connection outlives the virtual table, so this pointer is valid for the entire lifetime of VectorTable.